@@ -741,7 +741,9 @@ class CdnClient(AbstractClient):
 
 
     def DescribeIpStatus(self, request):
-        """DescribeIpStatus 用于查询域名所在加速平台的边缘节点、回源节点明细。注意事项：边缘节点（edge）尚未全量开放，未在内测名单中的账号不支持调用
+        """DescribeIpStatus 用于查询域名所在加速平台的边缘节点、回源节点明细。注意事项：边缘节点（edge）尚未全量开放，未在内测名单中的账号不支持调用。
+
+        >?  若您的业务已迁移至 CDN 控制台，请参考<a href="https://cloud.tencent.com/document/api/228/41954"> CDN 接口文档</a>，使用  CDN 相关API 进行操作。
 
         :param request: Request instance for DescribeIpStatus.
         :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeIpStatusRequest`
@@ -1034,6 +1036,34 @@ class CdnClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeScdnBotData(self, request):
+        """获取BOT统计数据列表
+
+        :param request: Request instance for DescribeScdnBotData.
+        :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeScdnBotDataRequest`
+        :rtype: :class:`tencentcloud.cdn.v20180606.models.DescribeScdnBotDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeScdnBotData", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeScdnBotDataResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeScdnBotRecords(self, request):
         """查询BOT会话记录列表
 
