@@ -313,38 +313,6 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def DescribeTrtcInteractiveTime(self, request):
-        """查询音视频互动计费时长。
-        - 查询时间小于等于1天时，返回每5分钟粒度的数据；查询时间大于1天时，返回按天汇总的数据。
-        - 单次查询统计区间最多不能超过31天。
-        - 若查询当天用量，由于统计延迟等原因，返回数据可能不够准确。
-        - 日结后付费将于次日上午推送账单，建议次日上午9点以后再来查询前一天的用量。
-
-        :param request: Request instance for DescribeTrtcInteractiveTime.
-        :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeTrtcInteractiveTimeRequest`
-        :rtype: :class:`tencentcloud.trtc.v20190722.models.DescribeTrtcInteractiveTimeResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeTrtcInteractiveTime", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeTrtcInteractiveTimeResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def DescribeTrtcMcuTranscodeTime(self, request):
         """查询旁路转码计费时长。
         - 查询时间小于等于1天时，返回每5分钟粒度的数据；查询时间大于1天时，返回按天汇总的数据。
